==================
Installing Kernels
==================

This information gives a high-level view of using Jupyter Notebook with
different programming languages (kernels).

Are any languages pre-installed?
================================

Yes, installing the Jupyter Notebook will also install the
`IPython <https://ipython.readthedocs.io/en/latest/>`_ :term:`kernel`. This
allows working on notebooks using the Python programming language.


How do I install Python 2 and Python 3?
=======================================

To install an additional version of Python, i.e. to have both Python 2 and 3
available, see the IPython docs on
`installing kernels <https://ipython.readthedocs.io/en/latest/install/kernel_install.html>`_.


How do I install other languages like R or Julia?
=================================================

To run notebooks in languages other than Python, such as R or Julia, you will
need to install additional kernels. For more information, see the full
`list of available kernels`_.

.. seealso::

    :doc:`Jupyter Projects </install>`
        Detailed installation instructions for individual Jupyter or IPython
        projects.

    :ref:`Kernels <kernels-langs>`
        Information about additional programming language kernels.

    :ref:`Kernels documentation for Jupyter client <kernels>`
        Technical information about kernels.

.. _`list of available kernels`: https://github.com/jupyter/jupyter/wiki/Jupyter-kernels
